@@ -1,7 +1,7 @@
 #-*- coding:utf-8 -*-
 
 #  Pybik -- A 3 dimensional magic cube game.
-#  Copyright © 2009-2013  B. Clausius <barcc@gmx.de>
+#  Copyright © 2009-2014  B. Clausius <barcc@gmx.de>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -92,7 +92,7 @@ class CubeState (object):
         for index, (pos, rot) in enumerate(self._blocksn):
             if rot != allrot:
                 return False  # Cubie rotated
-            block = self.model.rotated_position[index, rot]
+            block = self.model.rotated_position[rot][index]
             if pos != block:
                 return False  # Cubie at wrong place
         return True
