@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
-#  Copyright © 2012-2013  B. Clausius <barcc@gmx.de>
+#  Copyright © 2012-2014  B. Clausius <barcc@gmx.de>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -143,9 +143,10 @@ class Block (object):
         self.inplace_rotations = []
         
     def init_inplace_rotations(self, model):
-        for (blocknum, rotsym), blocknum2 in model.rotated_position.items():
-            if blocknum == blocknum2 == self.index and rotsym:
-                self.inplace_rotations.append(rotsym)
+        for rotsym, blocknum_blocknum2 in model.rotated_position.items():
+            for blocknum, blocknum2 in enumerate(blocknum_blocknum2):
+                if blocknum == blocknum2 == self.index and rotsym:
+                    self.inplace_rotations.append(rotsym)
         self.inplace_rotations = sorted(self.inplace_rotations, key=len)[:2]
         
     def __repr__(self):
@@ -376,7 +377,9 @@ class BrickModel (object):
                 coords = (np.matrix([block.coords]) * rotation).A.tolist()[0]
                 for p, pos in enumerate(self.blocks):
                     if pos.coords == coords:
-                        rotated_position[b, sym] = p
+                        if sym not in rotated_position:
+                            rotated_position[sym] = [0 for block in self.blocks]
+                        rotated_position[sym][b] = p
                         break
                 else:
                     assert False, 'not a permutation'
@@ -385,10 +388,10 @@ class BrickModel (object):
     @classmethod
     def get_datafilename(cls, sizes):
         x, y, unused_z = sizes
-        if x <= 2:
-            return 'mdata_01-02'
+        if x <= 3:
+            return 'mdata_01-03'
         else:
-            return 'mdata_{:02}_{}'.format(x, 0 if x<=5 else y%2 if x<=8 else y%3)
+            return 'mdata_{:02}_{}'.format(x, 0 if x<=6 else y%2 if x<=10 else y%3)
         
     def get_savedata(self):
         self.calc_data()
@@ -466,7 +469,7 @@ class BrickModel (object):
         
     def rotate_symbolic(self, axis, rdir, block, sym):
         rsym = (self.symbols if not rdir else self.symbolsI)[axis]
-        block = self.rotated_position[block, rsym]
+        block = self.rotated_position[rsym][block]
         sym = self.norm_symbol(sym + rsym)
         return block, sym
         
