@@ -1,7 +1,7 @@
 #-*- coding:utf-8 -*-
 
 #  Pybik -- A 3 dimensional magic cube game.
-#  Copyright © 2009, 2011-2013  B. Clausius <barcc@gmx.de>
+#  Copyright © 2009, 2011-2014  B. Clausius <barcc@gmx.de>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -85,9 +85,19 @@ class KeyStore (QObject):
                                   ('F', 'Ctrl+KP+5'), ('B', 'Ctrl+KP+0'),
                                  ],         lambda v: type(v) is list),
         'draw.zoom':            (1.0,       (0.1, 100.0)),
-        # The following 6 words are for the antialiasing levels: disabled, ugly, low, medium, high, higher
-        'draw.samples':         (3,         [N_('disabled'), N_('ugly'), N_('low'),
-                                             N_('medium'), N_('high'), N_('higher')]),
+        'draw.samples':         (3,         [
+                                # 6 Levels for antialiasing quality: disabled, ugly, low, medium, high, higher
+                                             N_('disabled'),
+                                # 6 Levels for antialiasing quality: disabled, ugly, low, medium, high, higher
+                                             N_('ugly'),
+                                # 6 Levels for antialiasing quality: disabled, ugly, low, medium, high, higher
+                                             N_('low'),
+                                # 6 Levels for antialiasing quality: disabled, ugly, low, medium, high, higher
+                                             N_('medium'),
+                                # 6 Levels for antialiasing quality: disabled, ugly, low, medium, high, higher
+                                             N_('high'),
+                                # 6 Levels for antialiasing quality: disabled, ugly, low, medium, high, higher
+                                             N_('higher')]),
         'draw.mirror_faces':    (False,     lambda v: type(v) is bool),
         'draw.mirror_distance': (2.1,       (0.1, 10.0)),
         'action.edit_moves':    ('Ctrl+L',  lambda v: type(v) is str),
