@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
-#  Copyright © 2012-2013  B. Clausius <barcc@gmx.de>
+#  Copyright © 2012-2014  B. Clausius <barcc@gmx.de>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 import sys, os
 sys.path.insert(0, '.')
-import pickle as pickle
+import pickle, pickletools
 from multiprocessing import Pool, cpu_count
 
 from pybiklib import model
@@ -118,25 +118,32 @@ def pool_create_modelfiledata(sizes_list):
     return savedata
     
 def pool_create_modelfile(args):
-    filename, fast = args
+    filename, fast, pickle_protocol = args
     sizes_list = pool_enum_modelfile(filename)
     savedata = pool_create_modelfiledata(sizes_list)
     if not fast:
         dedup_reset()
         savedata = pool_dedup(0, savedata)
+    savedata = pickle.dumps(savedata, pickle_protocol)
+    datasize = ['{:.1f} kb'.format(len(savedata) / 1000), '---']
+    if not fast:
+        savedata = pickletools.optimize(savedata)
+        datasize[1] = '{:.1f} kb'.format(len(savedata) / 1000)
     with open(filename, 'wb') as datafile:
-        pickle.dump(savedata, datafile, -1)
+        datafile.write(savedata)
     vals = ['%6s' % v for v in cnt_values]
     dups = ['%6s' % d for d in cnt_dups]
-    return 'generated {} with {} models\n  vals: {}\n  dups: {}'.format(
-                    filename, len(sizes_list), ' '.join(vals), ' '.join(dups))
+    return 'generated {} with {} models ({}, {})\n  vals: {}\n  dups: {}'.format(
+                    filename, len(sizes_list),
+                    datasize[0], datasize[1],
+                    ' '.join(vals), ' '.join(dups))
     
-def create_modeldata(dirname, testfunc=None, parallel=1, fast=False):
+def create_modeldata(dirname, testfunc=None, parallel=1, fast=False, pickle_protocol=-1):
     if testfunc is None:
         testfunc = lambda arg: True
     imap_model = pool_functions(parallel)
     modelfiles = enum_modelfiles(dirname, testfunc)
-    for lines in imap_model(pool_create_modelfile, [(m, fast) for m in modelfiles]):
+    for lines in imap_model(pool_create_modelfile, [(m, fast, pickle_protocol) for m in modelfiles]):
         print(lines)
         sys.stdout.flush()
     
